/*  -------------------------------------------------------------------------- 
    Program  :  FF17.sas

    Author   :  Perry Watts
    Date     :  Thursday, July 12, 2007

    Project  :  N07 ChartBasics Paper (FF17)
    Purpose  :  Create the plots to be included in the paper and presentation

    Notes    :  Full Reference:
                Charting the Basics with PROC GCHART. 
                Proceedings of the 20th Annual Northeast SAS Users Group Conference.
                Baltimore, MD, 2007, paper #FF17.

    Input    :  Mostly Miron's data reproduced by permission from SI
    Output   :  Figures (emf files)
    ------------------------------------------------------------------------  */
footnote1;

libname N07 'c:\N07\ChartBasics\Data';
options mautosource;
options sasautos=(sasautos 'c:\sasautogrf');
%delgCat(work.gseg);

goptions reset=goptions;
pattern1;
pattern2;
pattern3;
axis1;
axis2;
axis3;

goptions device=emf gunit=pct rotate=landscape ftext="Arial";

proc format;
  /* CHANGE ORDER FORMAT */  
   value $deptfm 'SHIP'='1) Shipping' 'ACCOUNTS'='2) Accounts' 'MARKET'='3) Marketing';
  /* LONG TEXT FORMAT */  
  value $dptLfm 'ACCOUNTS'='Accounts Payable' 'MARKET'='Marketing' 'SHIP'='Shipping';
  /* SKIP FORMAT ~*/
  value $dptSfm 'ACCOUNTS'='Accounts~Payable' 'MARKET'='Marketing' 'SHIP'='Shipping';
  /* MONTH FORMAT - TO GET THE RIGHT ORDER */
  value monthFmt 1=Jan 2=Feb 3=Mar 4=Apr 5=May 6=Jun 7=Jul 8=Aug 9=Sep 10=Oct 11=Nov 12=Dec;
run;
  
title1 "Count of Meetings by Department";
filename chrt1 'c:\N07\ChartBasics\Paper\EMF\chrt1.emf';
goptions htext=10pt htitle=12pt gsfname=chrt1;
proc gchart data=N07.meetings;
  title2 "(Default Width Bars)";
  vbar dept;
run;
quit;

title2 "(Fatter Bars)";
filename chrt2 'c:\N07\ChartBasics\Paper\EMF\chrt2.emf';
goptions htext=13pt htitle=15pt gsfname=chrt2;
proc gchart data=N07.meetings;
  vbar dept/width=15;
run;
quit;

/* OUR FIRST ENHANCEMENTS */
pattern1 color=grayCC;
axis1 label=(a=90 f="Arial/Bold" "Number of Meetings")
      order=(0 to 14 by 2) minor=(n=1);
axis2 label=(f="Arial/Bold" "Department");

title2 '(FREQ Chart Enhanced)';
filename chrt3 'c:\N07\ChartBasics\Paper\EMF\chrt3.emf';
goptions htext=13pt htitle=15pt gsfname=chrt3;
proc gchart data=N07.meetings;
  vbar dept /
     width=15
     outside=freq
     raxis=axis1
     maxis=axis2
     coutline=black
     woutline=1;
run;
quit;

/* CREATING PERCENT MEAN AND SUM CHARTS*/
pattern1 color=grayCC;
axis1 label=none order=(0 to 45 by 15) minor=(n=2)
  value=('0%' '15%' '30%' '45%');
axis2 label=(f="Arial/Bold" "Department");
title1 'Percentage of Meetings by Department';
title2 '(Frequencies are listed INSIDE)';
filename chrt4 'c:\N07\ChartBasics\Paper\EMF\chrt4.emf';
goptions htext=13pt htitle=15pt gsfname=chrt4;
proc gchart data=N07.meetings;
  vbar dept /
    width=15 type=PCT
    inside=FREQ outside=PCT
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
run;
quit;

pattern1 color=grayCC;
axis1 label=(f="Arial/Bold" "Hours") minor=NONE;
axis2 label=(f="Arial/Bold" "Department");
title1 'Average Length of Meetings by Department';
title2 '(Frequencies are listed INSIDE)';
filename chrt5 'c:\N07\ChartBasics\Paper\EMF\chrt5.emf';
goptions htext=13pt htitle=15pt gsfname=chrt5;
proc gchart data=N07.meetings;
  vbar dept /
    width=15 type=MEAN
    inside=FREQ outside=MEAN sumvar=Hours
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
run;
quit;

pattern1 color=grayCC;
axis1 label=(f="Arial/Bold" "Hours") minor=(n=1);
axis2 label=(f="Arial/Bold" "Department");
title1 'Total Length of Meetings by Department';
title2 '(Average Lengths are listed INSIDE)';
filename chrt6 'c:\N07\ChartBasics\Paper\EMF\chrt6.emf';
goptions htext=13pt htitle=15pt gsfname=chrt6;
proc gchart data=N07.meetings;
  vbar dept /
    width=15 type=SUM
    inside=MEAN outside=SUM sumvar=Hours
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
run;
quit;

/* CHANGING THE ORDER OF THE MIDPOINTS*/
pattern1 color=grayCC;
axis1 label=(f="Arial/Bold" "Hours") minor=(n=1);
axis2 label=(f="Arial/Bold" "Department");
title1 'Total Length of Meetings by Department';
title2 '(Order Determined by MIDPOINTS)';
filename chrt7 'c:\N07\ChartBasics\Paper\EMF\chrt7.emf';
goptions htext=13pt htitle=15pt gsfname=chrt7;
proc gchart data=N07.meetings;
  vbar dept /
    width=15 type=SUM
    inside=MEAN outside=SUM sumvar=Hours
    midpoints="MARKET" "ACCOUNTS" "SHIP"
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
run;
quit;

pattern1 color=grayCC;
axis1 label=(f="Arial/Bold" "Hours") minor=(n=1);
axis2 label=(f="Arial/Bold" "Department");
title1 'Total Length of Meetings by Department';
title2 '(Order Determined by DESCENDING)';
filename chrt8 'c:\N07\ChartBasics\Paper\EMF\chrt8.emf';
goptions htext=13pt htitle=15pt gsfname=chrt8;
proc gchart data=N07.meetings;
  vbar dept /
    width=15 type=SUM
    inside=MEAN outside=SUM sumvar=Hours
    descending
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
run;
quit;

  /* NOT included in paper - change order by formatting */

pattern1 color=grayCC;
axis1 label=(f="Arial/Bold" "Hours") minor=(n=1);
axis2 label=(f="Arial/Bold" "Department");
title1 'Total Length of Meetings by Department';
title2 '(Order Determined by FORMAT)';
filename chrt9 'c:\N07\ChartBasics\Paper\EMF\chrt9.emf';
goptions htext=13pt htitle=15pt gsfname=chrt9;
proc gchart data=N07.meetings;
  vbar dept /
    width=15 type=SUM
    inside=MEAN outside=SUM sumvar=Hours
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
  format dept $deptfm.;
run;
quit;

/* SOLUTIONS TO TEXT OVERFLOW FOR MIDPOINT AXIS VALUES */
/* Lengthen text with the $DPTLFM format */


/* DEFAULT IN V9 ILLUSTRATED BY CGM DRIVER*/
goptions reset=goptions;
filename chrt10 'c:\N07\ChartBasics\Paper\EMF\chrt10.cgm';
goptions device=CGMOFML gunit=pct rotate=landscape ftext=HWCGM001;
goptions htext=13pt htitle=15pt gsfname=chrt10;
pattern1 color=grayCC;
axis1 label=(f=HWCGM002 "Hours") minor=(n=1);
axis2 label=(f=HWCGM002 "Department");
title1 'Total Length of Meetings by Department';
title2 '(V9 CGM Driver: htext=13pt width=11)';
proc gchart data=N07.meetings;
  vbar dept /
    width=11 type=SUM
    inside=MEAN outside=SUM sumvar=Hours
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
  format dept $dptLfm.;
run;
quit;

/* DEFAULT IN V9 EMF DRIVER IS MORE ATROCIOUS*/
goptions reset=goptions;
filename chrt11 'c:\N07\ChartBasics\Paper\EMF\chrt11.emf';
goptions device=emf gunit=pct rotate=landscape ftext="Arial";
goptions htext=13pt htitle=15pt gsfname=chrt11;
pattern1 color=grayCC;
title1 'Total Length of Meetings by Department';
title2 '(V9 EMF Driver: htext=13pt width=10)';
proc gchart data=N07.meetings;
  vbar dept /
    width=10 type=SUM
    inside=MEAN outside=SUM sumvar=Hours
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
  format dept $dptLfm.;
run;
quit;

/* ALTERNATIVE #1: REDUCE TEXT SIZE OF AXIS VALUES ONLY */
filename chrt12 'c:\N07\ChartBasics\Paper\EMF\chrt12.emf';
goptions htext=13pt htitle=15pt gsfname=chrt12;
pattern1 color=grayCC;
title1 'Total Length of Meetings by Department';
title2 '(V9 EMF Driver: value text=8pt width=10)';
axis1 label=(f="Arial/Bold" "Hours") value=(h=8pt) minor=(n=1);
axis2 label=(f="Arial/Bold" "Department") value=(h=8pt);

proc gchart data=N07.meetings;
  vbar dept /
    width=10 type=SUM
    inside=MEAN outside=SUM sumvar=Hours
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
  format dept $dptLfm.;
run;
quit;

/* ALTERNATIVE #2: SPLIT */

filename chrt13 'c:\N07\ChartBasics\Paper\EMF\chrt13.emf';
goptions htext=13pt htitle=15pt gsfname=chrt13;
pattern1 color=grayCC;
title1 'Total Length of Meetings by Department';
title2 '(V9 EMF Driver SPLIT with a format: htext=13pt width=10)';
axis1 label=(f="Arial/Bold" "Hours")  minor=(n=1);
axis2 label=(f="Arial/Bold" "Department") split="~";

proc gchart data=N07.meetings;
  vbar dept /
    width=10 type=SUM
    inside=MEAN outside=SUM sumvar=Hours
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
  format dept $dptSfm.;
run;
quit;

/* ALTERNATIVE #3 INCREASE BAR WIDTH */
filename chrt14 'c:\N07\ChartBasics\Paper\EMF\chrt14.emf';
goptions htext=13pt htitle=15pt gsfname=chrt14;
pattern1 color=grayCC;
title1 'Total Length of Meetings by Department';
title2 '(V9 EMF Driver: htext=13pt width=18)';
axis1 label=(f="Arial/Bold" "Hours")  minor=(n=1);
axis2 label=(f="Arial/Bold" "Department");

proc gchart data=N07.meetings;
  vbar dept /
    width=18 type=SUM
    inside=MEAN outside=SUM sumvar=Hours
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
  format dept $dptLfm.;
run;
quit;

/* ALTERNATIVE #4: CHANGE TO HBAR BUT:
     meanLabel='Mean Hours' is not supported.
     Also cannot get rid of freqs. All or nothing with HBAR
     Also WIDTH of 10 is not supported. Different Scale for cells Horizontally, Vertically*/
filename chrt15 'c:\N07\ChartBasics\Paper\EMF\chrt15.emf';
goptions htext=13pt htitle=15pt gsfname=chrt15;
pattern1 color=grayCC;
title1 'Total Length of Meetings by Department';
title2 '(V9 EMF Driver HBAR: htext=13pt width=3.5)';
axis1 label=(f="Arial/Bold" "Hours")  minor=(n=1);
axis2 label=(f="Arial/Bold" "Department") ;

proc gchart data=N07.meetings;
  HBAR dept /
    width=3.25 type=SUM
    sumvar=Hours
    freqlabel='n' sumlabel='Total Hours'
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
  format dept $dptLfm.;
run;
quit;

/* V9 EMF DRIVER IS NOT RESTRICTED TO BAR WIDTH */
filename chrt16 'c:\N07\ChartBasics\Paper\EMF\chrt16.emf';
goptions htext=13pt htitle=15pt gsfname=chrt16;
pattern1 color=grayCC;
axis1 label=(f="Arial/Bold" "Hours") minor=(n=1);
axis2 label=(f="Arial/Bold" "Department");
title1 'Total Length of Meetings by Department';
title2 '(V9 EMF Driver: htext=13pt width=12)';
proc gchart data=N07.meetings;
  vbar dept /
    width=12 type=SUM
    inside=MEAN outside=SUM sumvar=Hours
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
  format dept $dptLfm.;
run;
quit;

/* SUBGROUP BAR CHART*/
filename chrt17 'c:\N07\ChartBasics\Paper\EMF\chrt17.emf';
goptions htext=13pt htitle=15pt gsfname=chrt17;

pattern1 color=graydd; 
pattern2 color=VLIB; 
pattern3 color=PALG;
legend1
  across=1 shape=bar(3,2) label=("Room" position=(top center))
  cborder=black position=(top outside right) offset=(-7,-7);

axis1 label=(a=90 f="Arial/Bold" "Frequency") 
 order=(0 to 14 by 2) minor=(n=1);
axis2 label=(f="Arial/Bold" "Department");

title1 'Number of Meetings by Department';
title2 '(Subgroup Frequencies are listed INSIDE)';
proc gchart data=N07.meetings;
  vbar dept /
    width=15 type=FREQ
    outside=FREQ inside=Freq subgroup=room
    legend=legend1  raxis=axis1 maxis=axis2
    coutline=black woutline=1;
  format dept $dptLfm.;
run;
quit;

/* HIERARCHICAL GROUP BAR CHART*/
  /* SET LEGEND OPTIONS -- SEE PAGE 551 V8 MANUAL. CONVOLUTED RULES:
     LEGEND IS IGNORED IF:
     1) SUBGROUP= IS NOT USED.
     2) SPECIFIED LEGEND EFFECT IS NOT IN EFFECT (MUST HAVE LEGEND= IN /OPTIONS)
     3) THE NOLEGEND OPTION IS USED
     4) THE PATTERNID=IS SET TO ANYTHING OTHER THAN SUBGROUP (THAT IS BY, GROUP OR MIDPOINT)
        GET AROUND #4 WITH "VBAR TXORD / SUBGROUP=TXORD  */

filename chrt18 'c:\N07\ChartBasics\Paper\EMF\chrt18.emf';
goptions htext=13pt htitle=15pt gsfname=chrt18;

pattern1 color=blue; 
pattern2 color=graycc; 
pattern3 color=CX40AC40;
legend1
  across=1 shape=bar(3,2) label=("Department" h=11 pt position=left j=c)
  position=(top inside left) mode=share
  value=(h=9pt 'Accounts Payable' 'Marketing' 'Shipping');

axis1 label=(a=90 f="Arial/Bold" "Frequency") 
 order=(0 to 6 by 1) minor=NONE offset=(,8pct);
axis2 label=none value=none;
axis3 label=(j=c "Room");

title1 'Number of Meetings by Room';
title2 '(Within Room: by Department)';
proc gchart data=N07.meetings;
  vbar dept /
    width=15 type=FREQ outside=FREQ
    Group=Room patternID=subgroup
    legend=legend1 subgroup=dept raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
run;
quit;

 /* CREATE A NON-HIERARCHICAL GROUP BAR CHART WITH A SUBSET OF SASHELP.CLASS */
filename chrt19 'c:\N07\ChartBasics\Paper\EMF\chrt19.emf';
goptions htext=13pt htitle=15pt gsfname=chrt19;

pattern1 color=pink; 
pattern2 color=blue; 
 
axis1 label=(a=90 f="Arial/Bold" "Height (inches)") 
 order=(50 to 70 by 5) minor=(n=4);
axis2 label=NONE value=NONE;
axis3 label=none value=(f="Arial/Bold" "Girls" "Boys");

title1 'Height by Gender';
title2 '(for SASHELP.Class students ages 13-15)';
proc gchart data=N07.sasClass;
  vbar Name / 
    width=5 type=SUM sumvar=Height outside=SUM
    Group=sex patternID=group NOZERO
    raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
run;
quit;

 /* CREATE ERROR BARS */
filename chrt20 'c:\N07\ChartBasics\Paper\EMF\chrt20.emf';
goptions htext=13pt htitle=15pt gsfname=chrt20;

pattern1 color=grayCC;
axis1 label=(f="Arial/Bold" "Hours") minor=NONE;
axis2 label=(f="Arial/Bold" "Department");
title1 'Average Length of Meetings by Department';
title2 '(With 95% Confidence Limits)';
proc gchart data=N07.meetings;
  vbar dept /
    width=15 type=MEAN inside=MEAN
    errorbar=Top clm=95 sumvar=Hours
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
run;
quit;

 /* CREATE MIN/MAX CHART */
filename chrt21 'c:\N07\ChartBasics\Paper\EMF\chrt21.emf';
goptions htext=13pt htitle=15pt gsfname=chrt21;

pattern1 color=Blue;
pattern2 color=Red;
axis1 label=(a=90 'Temperature (Centigrade)') minor=(n=4) order=(-30 to 30 by 10);
axis2 label=('Month');
title1 'Average Temperature in Minneapolis';
title2 '(by Month)';

 proc gchart data=n07.MplsWeather; 
  vbar month / discrete noframe
    width=5 type=sum sumvar=TC
    subgroup=AboveZeroYvN nolegend
    raxis=axis1 maxis=axis2
    autoref clipref cref=graybb
    coutline=black woutline=1; 
  format month monthfmt.;
run;
quit;

 /* CONVERT MIN/MAX CHART INTO A 3-D CHART*/
filename chrt22 'c:\N07\ChartBasics\Paper\EMF\chrt22.emf';
goptions htext=13pt htitle=15pt gsfname=chrt22;

pattern1 color=Blue;
pattern2 color=Red;
axis1 label=(a=90 'Temperature (Centigrade)') minor=(n=4) order=(-30 to 30 by 10);
axis2 label=('Month');
title1 'Average Temperature in Minneapolis';
title2 '(by Month)';

 proc gchart data=n07.MplsWeather; 
  vbar3D month / discrete noframe
    shape=hexagon 
    width=5 type=sum sumvar=TC
    subgroup=AboveZeroYvN nolegend
    raxis=axis1 maxis=axis2
    autoref clipref cref=graybb
    coutline=black woutline=1; 
  format month monthfmt.;
run;
quit;

/* DEALING WITH NUMERIC MIDPOINTS IN PROC GCHART*/

/* NUMBER OF MEETINGS: DISCRETE DATA */
pattern1 color=grayCC;
axis1 label=(a=90 f="Arial/Bold" "Number of Meetings")
      order=(0 to 14 by 2) minor=(n=1);
axis2 label=(f="Arial/Bold" "Room");
title1 "Count of Meetings by Room";
title2 '(Original Room ID)';
filename chrt23 'c:\N07\ChartBasics\Paper\EMF\chrt23.emf';
goptions htext=13pt htitle=15pt gsfname=chrt23;
proc gchart data=N07.meetings;
  vbar room /
     width=15
     outside=freq
     raxis=axis1
     maxis=axis2
     coutline=black
     woutline=1;
run;
quit;

pattern1 color=grayCC;
axis1 label=(a=90 f="Arial/Bold" "Number of Meetings")
      order=(0 to 25 by 5) minor=(n=4);
axis2 label=(f="Arial/Bold" "Room Number");
title1 "Count of Meetings by Room";
title2 '(with Internally Calculated Midpoints)';
filename chrt24 'c:\N07\ChartBasics\Paper\EMF\chrt24.emf';
goptions htext=13pt htitle=15pt gsfname=chrt24;
proc gchart data=N07.meetings;
  vbar roomNumber /
     width=15
     outside=freq
     raxis=axis1
     maxis=axis2
     coutline=black
     woutline=1;
run;
quit;

pattern1 color=grayCC;
axis1 label=(a=90 f="Arial/Bold" "Number of Meetings")
      order=(0 to 25 by 5) minor=(n=4);
axis2 label=(f="Arial/Bold" "Room Number");
title1 "Count of Meetings by Room";
title2 '(Add to the Confusion with NOZERO )';
filename chrt25 'c:\N07\ChartBasics\Paper\EMF\chrt25.emf';
goptions htext=13pt htitle=15pt gsfname=chrt25;
proc gchart data=N07.meetings;
  vbar roomNumber / NOZERO
     width=15
     outside=freq
     raxis=axis1
     maxis=axis2
     coutline=black
     woutline=1;
run;
quit;

pattern1 color=grayCC;
axis1 label=(a=90 f="Arial/Bold" "Number of Meetings")
      order=(0 to 14 by 2) minor=(n=1);
axis2 label=(f="Arial/Bold" "Room Number");
title1 "Count of Meetings by Room";
title2 '(Fixed with the DISCRETE Option)';
filename chrt26 'c:\N07\ChartBasics\Paper\EMF\chrt26.emf';
goptions htext=13pt htitle=15pt gsfname=chrt26;
proc gchart data=N07.meetings;
  vbar roomNumber / discrete
     width=15
     outside=freq
     raxis=axis1
     maxis=axis2
     coutline=black
     woutline=1;
run;
quit;

/* HOURS: CONTINUOUS DATA */
pattern1 color=grayCC;
axis1 label=(a=90 f="Arial/Bold" "Number of Meetings")
      order=(0 to 10 by 2) minor=(n=1);
axis2 label=(f="Arial/Bold" "Hours");
title1 "Count of Meetings by their Length";
title2 '(With Internally Calculated Midpoints)';
filename chrt27 'c:\N07\ChartBasics\Paper\EMF\chrt27.emf';
goptions htext=13pt htitle=15pt gsfname=chrt27;
proc gchart data=N07.meetings;
 vbar hours / space=0
  width=10 outside=freq raxis=axis1
  maxis=axis2 coutline=black woutline=1;
run;
quit;

pattern1 color=grayCC;
axis1 label=(a=90 f="Arial/Bold" "Number of Meetings")
      order=(0 to 8 by 2) minor=(n=1);
axis2 label=(f="Arial/Bold" "Hours");
title1 "Count of Meetings by their Length";
title2 '(Actual Hours with Discrete Option)';
filename chrt28 'c:\N07\ChartBasics\Paper\EMF\chrt28.emf';
goptions htext=13pt htitle=15pt gsfname=chrt28;
proc gchart data=N07.meetings;
 vbar hours / discrete space=1
  width=7 outside=freq raxis=axis1
  maxis=axis2 coutline=black woutline=1;
run;
quit;

pattern1 color=grayCC;
axis1 label=(a=90 f="Arial/Bold" "Number of Meetings")
      order=(0 to 12 by 3) minor=(n=2);
axis2 label=(f="Arial/Bold" "Hours");
title1 "Count of Meetings by their Length";
title2 '(Levels with Range)';
filename chrt29 'c:\N07\ChartBasics\Paper\EMF\chrt29.emf';
goptions htext=13pt htitle=15pt gsfname=chrt29;
proc gchart data=N07.meetings;
 vbar hours / levels=4 range space=0
  width=15 outside=freq raxis=axis1
  maxis=axis2 coutline=black woutline=1;
run;
quit;

/* PIE CHART */
pattern1 color=graydd; 
pattern2 color=VLIB; 
pattern3 color=PALG;
title1 "Count of Meetings by Room";
filename chrt30 'c:\N07\ChartBasics\Paper\EMF\chrt30.emf';
goptions htext=13pt htitle=15pt gsfname=chrt30;
proc gchart data=N07.meetings;
  pie room /
  noheading percent=arrow slice=inside value=inside
  coutline=black woutline=2;
run;
quit;

/* DONUT CHART FOR SUBGROUP */
legend1 label=none shape=bar(4,3) 
  position=(bottom center) across=3 mode=share;
pattern1 color=graydd; 
pattern2 color=VLIB; 
pattern3 color=PALG;
title1 "Lengths of Meetings by Room and Department";
filename chrt31 'c:\N07\ChartBasics\Paper\EMF\chrt31.emf';
goptions htext=13pt htitle=15pt gsfname=chrt31;
proc gchart data=N07.meetings;
  donut room /
  noheading sumvar=hours subgroup=dept
  donutpct=30 label=('For' j=c '11 Months')
  legend=legend1 coutline=black woutline=2;
run;
quit;

  /* STAR CHARTS - BEFORE OVERLAY */
pattern1 color=graydd; 
pattern2 color=VLIB; 
pattern3 color=PALG;
title1 "Lengths of Meetings by Room";
filename chrt32 'c:\N07\ChartBasics\Paper\EMF\chrt32.emf';
goptions htext=13pt htitle=15pt gsfname=chrt32;
proc gchart data=N07.meetings;
  star room /
  noheading
  sumvar=hours
  fill=s
  coutline=black woutline=1;
run;
quit;

pattern1; 
pattern2; 
pattern3; 
title1 "Lengths of Meetings by Room";
filename chrt33 'c:\N07\ChartBasics\Paper\EMF\chrt33.emf';
goptions htext=13pt htitle=15pt gsfname=chrt33;
proc gchart data=N07.meetings;
  star room /
  noheading
  sumvar=hours
  noconnect
  coutline=red woutline=1;
run;
quit;

/* OVERLAY STAR CHARTS STARA AND STARB */
goptions nodisplay  htext=13pt htitle=15pt;
pattern1 color=graydd; 
pattern2 color=VLIB; 
pattern3 color=PALG;
title1 "Lengths of Meetings by Room";
proc gchart data=N07.meetings;
 star room / noheading name="starA"
 sumvar=hours fill=s coutline=black woutline=1;
run;
quit;

proc gchart data=N07.meetings;
 star room / noheading name="starB"
 sumvar=hours noconnect fill=none coutline=red woutline=1;
run;
quit;
filename chrt34 'c:\N07\ChartBasics\Paper\EMF\chrt34.emf';
goptions display gsfname=chrt34 gsfmode=replace;

proc greplay nofs igout=work.gseg tc=tempCat;
 tdef T1X1
 1/llx=0 ulx=0 urx=100 lrx=100
   lly=0 uly=100 ury=100 lry=0;
   template=T1X1;
 treplay 1:StarA 1:StarB;
run;
quit;

/* OVERLAY STAR CHARTS STARC AND STARD */
goptions nodisplay  htext=13pt htitle=15pt;
pattern1 color=Blue; pattern2 color=Blue; pattern3 color=Blue;
pattern4 color=red; pattern5 color=red; pattern6 color=red; pattern7 color=red;
pattern8 color=red; pattern9 color=red; pattern10 color=red; pattern11 color=red;
pattern12 color=blue;

title1 'Average Temperature in Minneapolis';
title2 '(by Month)';

 proc gchart data=n07.MplsWeather; 
  star month / discrete noheading name="StarC"
    type=sum sumvar=TC fill=s
    coutline=white woutline=1; 
    format month monthfmt.;
run;
quit;

 proc gchart data=n07.MplsWeather; 
  star month / discrete noheading name="StarD"
    type=sum sumvar=TC fill=none noconnect
    coutline=black woutline=1; 
    format month monthfmt.;
run;
quit;

filename chrt35 'c:\N07\ChartBasics\Paper\EMF\chrt35.emf';
goptions display gsfname=chrt35 gsfmode=replace;

proc greplay nofs igout=work.gseg tc=tempCat;
 tdef T1X1
 1/llx=0 ulx=0 urx=100 lrx=100
   lly=0 uly=100 ury=100 lry=0;
   template=T1X1;
 treplay 1:StarC 1:StarD;
run;
quit;
